pyprocar.scripts.FermiHandler — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.scripts.FermiHandler

class pyprocar.scripts.FermiHandler(code: str, dirname: str = '', fermi: float | None = None, repair: bool = False, apply_symmetry: bool = True)

  Methods

  `FermiHandler.__init__`(code[, dirname, ...]) | This class handles the plotting of the fermi surface.
  `FermiHandler.create_isovalue_gif`(mode[, ...]) | A method to plot the 3d fermi surface
  `FermiHandler.plot_fermi_cross_section`(mode) | A method to plot the 3d fermi surface
  `FermiHandler.plot_fermi_cross_section_box_widget`(mode) | A method to plot the 3d fermi surface
  `FermiHandler.plot_fermi_isoslider`(mode[, ...]) | A method to plot the 3d fermi surface
  `FermiHandler.plot_fermi_surface`(mode[, ...]) | A method to plot the 3d fermi surface
  `FermiHandler.print_default_settings`() | Prints all the configuration settings with their current values.